@@ -20,7 +20,7 @@
 #include <tqobjectlist.h>
 #include <tdelocale.h>
 #include <kiconloader.h>
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdeaboutapplication.h>
 
 #include <twin.h>
